.. image:: https://img.shields.io/pypi/l/xspline
    :target: https://github.com/zhengp0/xspline/blob/main/LICENSE

.. image:: https://img.shields.io/pypi/v/xspline
    :target: https://pypi.org/project/xspline

.. image:: https://img.shields.io/github/actions/workflow/status/zhengp0/xspline/python-build.yml?branch=main
    :target: https://github.com/zhengp0/xspline/actions

.. image:: https://img.shields.io/badge/docs-here-green
    :target: https://zhengp0.github.io/xspline

.. image:: https://codecov.io/gh/zhengp0/xspline/branch/main/graph/badge.svg?token=WUV5OR77N8 
    :target: https://codecov.io/gh/zhengp0/xspline

.. image:: https://app.codacy.com/project/badge/Grade/308cc2771871498fbcdaee3440e56ad0
    :target: https://app.codacy.com/gh/zhengp0/xspline/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade


XSpline
=======

Advanced spline package that provides b-spline bases, their derivatives and integrals.


* `Installation <https://zhengp0.github.io/xspline/installation.html>`_
* `Quickstart <https://zhengp0.github.io/xspline/quickstart.html>`_
